RomanNumeralsType enum

Selects which family of Roman numerals to recognise and produce.

See CommonRomanNumeralsConfig, ApostrophusRomanNumeralsConfig, and VinculumRomanNumeralsConfig for the concrete styles.

Inheritance
Available extensions

Values

apostrophus → const RomanNumeralsType
common → const RomanNumeralsType
vinculum → const RomanNumeralsType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RomanNumeralsType>
A constant List of the values in this enum, in order of their declaration.