VinculumRomanNumeralsConfig class

Vinculum (overlined) form. An overline (combining U+0305) over a letter multiplies its value by 1,000:

Value Letter
5,000
10,000
50,000
100,000
500,000
1,000,000

Maximum representable value: 3,999,999 / M̅M̅M̅C̅M̅X̅C̅MX̅CMXCIX.

At the 1,000s position plain M is preferred over (which is not used in this implementation).

Note: U+0305 (combining overline) is preferred over U+0304 (combining macron) since the vinculum originates in mathematics and is a line, not a diacritical mark.

Inheritance

Constructors

VinculumRomanNumeralsConfig({String? nulla})
const

Properties

configType RomanNumeralsType
Which numeral style this config selects.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
nulla String?
Optional zero-token (e.g. 'N'). When null, zero is unsupported.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited